# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wd_domain_service.api_client import ApiClient
from dhicn_wd_domain_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ScheduleApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_domain_wd_schedule_curve_list_get(self, item_types, scenario_id, **kwargs):  # noqa: E501
        """获取curve 的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_curve_list_get(item_types, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] item_types: (required)
        :param str scenario_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CurveInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_curve_list_get_with_http_info(item_types, scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_curve_list_get_with_http_info(self, item_types, scenario_id, **kwargs):  # noqa: E501
        """获取curve 的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_curve_list_get_with_http_info(item_types, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] item_types: (required)
        :param str scenario_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CurveInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'item_types',
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_curve_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'item_types' is set
        if self.api_client.client_side_validation and ('item_types' not in local_var_params or  # noqa: E501
                                                        local_var_params['item_types'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `item_types` when calling `api_v1_domain_wd_schedule_curve_list_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_curve_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'item_types' in local_var_params and local_var_params['item_types'] is not None:  # noqa: E501
            query_params.append(('ItemTypes', local_var_params['item_types']))  # noqa: E501
            collection_formats['ItemTypes'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/curve/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CurveInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_curve_timeseries_get(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """获取curve 时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_curve_timeseries_get(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CurveTsInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_curve_timeseries_get_with_http_info(model_feature_id, scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_curve_timeseries_get_with_http_info(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """获取curve 时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_curve_timeseries_get_with_http_info(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CurveTsInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_feature_id',
            'scenario_id',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_curve_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'model_feature_id' is set
        if self.api_client.client_side_validation and ('model_feature_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['model_feature_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `model_feature_id` when calling `api_v1_domain_wd_schedule_curve_timeseries_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_curve_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_feature_id' in local_var_params and local_var_params['model_feature_id'] is not None:  # noqa: E501
            query_params.append(('ModelFeatureId', local_var_params['model_feature_id']))  # noqa: E501
            collection_formats['ModelFeatureId'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/curve/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CurveTsInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_curve_timeseries_update_post(self, **kwargs):  # noqa: E501
        """更新curve 时间序列数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_curve_timeseries_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCurveTsInput update_curve_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_curve_timeseries_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_curve_timeseries_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新curve 时间序列数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_curve_timeseries_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCurveTsInput update_curve_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_curve_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_curve_timeseries_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_curve_ts_input' in local_var_params:
            body_params = local_var_params['update_curve_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/curve/timeseries/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_pattern_list_get(self, item_types, scenario_id, **kwargs):  # noqa: E501
        """获取Pattern 的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pattern_list_get(item_types, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] item_types: (required)
        :param str scenario_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PatternInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_pattern_list_get_with_http_info(item_types, scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_pattern_list_get_with_http_info(self, item_types, scenario_id, **kwargs):  # noqa: E501
        """获取Pattern 的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pattern_list_get_with_http_info(item_types, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] item_types: (required)
        :param str scenario_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PatternInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'item_types',
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_pattern_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'item_types' is set
        if self.api_client.client_side_validation and ('item_types' not in local_var_params or  # noqa: E501
                                                        local_var_params['item_types'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `item_types` when calling `api_v1_domain_wd_schedule_pattern_list_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_pattern_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'item_types' in local_var_params and local_var_params['item_types'] is not None:  # noqa: E501
            query_params.append(('ItemTypes', local_var_params['item_types']))  # noqa: E501
            collection_formats['ItemTypes'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/pattern/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PatternInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_pattern_timeseries_get(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """获取pattern 时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pattern_timeseries_get(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PatternTsInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_pattern_timeseries_get_with_http_info(model_feature_id, scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_pattern_timeseries_get_with_http_info(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """获取pattern 时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pattern_timeseries_get_with_http_info(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PatternTsInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_feature_id',
            'scenario_id',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_pattern_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'model_feature_id' is set
        if self.api_client.client_side_validation and ('model_feature_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['model_feature_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `model_feature_id` when calling `api_v1_domain_wd_schedule_pattern_timeseries_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_pattern_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_feature_id' in local_var_params and local_var_params['model_feature_id'] is not None:  # noqa: E501
            query_params.append(('ModelFeatureId', local_var_params['model_feature_id']))  # noqa: E501
            collection_formats['ModelFeatureId'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/pattern/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PatternTsInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_pattern_timeseries_update_post(self, **kwargs):  # noqa: E501
        """更新Pattern 时间序列数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pattern_timeseries_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePatternTsInput update_pattern_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_pattern_timeseries_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_pattern_timeseries_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新Pattern 时间序列数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pattern_timeseries_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePatternTsInput update_pattern_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_pattern_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_pattern_timeseries_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_pattern_ts_input' in local_var_params:
            body_params = local_var_params['update_pattern_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/pattern/timeseries/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_pump_list_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取泵的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pump_list_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PumpInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_pump_list_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_pump_list_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取泵的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pump_list_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PumpInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_pump_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_pump_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/pump/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PumpInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_pump_timeseries_get(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """/api/v1/domain-wd/schedule/pump/timeseries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pump_timeseries_get(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ControlTsInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_pump_timeseries_get_with_http_info(model_feature_id, scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_pump_timeseries_get_with_http_info(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """/api/v1/domain-wd/schedule/pump/timeseries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pump_timeseries_get_with_http_info(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ControlTsInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_feature_id',
            'scenario_id',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_pump_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'model_feature_id' is set
        if self.api_client.client_side_validation and ('model_feature_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['model_feature_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `model_feature_id` when calling `api_v1_domain_wd_schedule_pump_timeseries_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_pump_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_feature_id' in local_var_params and local_var_params['model_feature_id'] is not None:  # noqa: E501
            query_params.append(('ModelFeatureId', local_var_params['model_feature_id']))  # noqa: E501
            collection_formats['ModelFeatureId'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/pump/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ControlTsInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_pump_timeseries_update_post(self, **kwargs):  # noqa: E501
        """更新时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pump_timeseries_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlTsInput update_control_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_pump_timeseries_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_pump_timeseries_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_pump_timeseries_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlTsInput update_control_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_control_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_pump_timeseries_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_control_ts_input' in local_var_params:
            body_params = local_var_params['update_control_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/pump/timeseries/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_valve_list_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取阀的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_valve_list_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ValveInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_valve_list_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_valve_list_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取阀的列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_valve_list_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ValveInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_valve_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_valve_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/valve/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ValveInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_valve_timeseries_get(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """获取阀时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_valve_timeseries_get(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ControlTsInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_valve_timeseries_get_with_http_info(model_feature_id, scenario_id, **kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_valve_timeseries_get_with_http_info(self, model_feature_id, scenario_id, **kwargs):  # noqa: E501
        """获取阀时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_valve_timeseries_get_with_http_info(model_feature_id, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] model_feature_id: (required)
        :param str scenario_id: (required)
        :param str start_time:
        :param str end_time:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ControlTsInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_feature_id',
            'scenario_id',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_valve_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'model_feature_id' is set
        if self.api_client.client_side_validation and ('model_feature_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['model_feature_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `model_feature_id` when calling `api_v1_domain_wd_schedule_valve_timeseries_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_domain_wd_schedule_valve_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_feature_id' in local_var_params and local_var_params['model_feature_id'] is not None:  # noqa: E501
            query_params.append(('ModelFeatureId', local_var_params['model_feature_id']))  # noqa: E501
            collection_formats['ModelFeatureId'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/valve/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ControlTsInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_schedule_valve_timeseries_update_post(self, **kwargs):  # noqa: E501
        """更新阀时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_valve_timeseries_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlTsInput update_control_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_schedule_valve_timeseries_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_schedule_valve_timeseries_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新阀时序数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_schedule_valve_timeseries_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlTsInput update_control_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_control_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_schedule_valve_timeseries_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_control_ts_input' in local_var_params:
            body_params = local_var_params['update_control_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/schedule/valve/timeseries/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class GetFilterModelResultInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'data_type': 'SysWdDataTypeEnum',
        'time': 'datetime',
        'filter_conditions': 'FilterConditionEnum',
        'condition_value': 'list[float]'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'data_type': 'dataType',
        'time': 'time',
        'filter_conditions': 'filterConditions',
        'condition_value': 'conditionValue'
    }

    def __init__(self, scenario_id=None, data_type=None, time=None, filter_conditions=None, condition_value=None, local_vars_configuration=None):  # noqa: E501
        """GetFilterModelResultInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._data_type = None
        self._time = None
        self._filter_conditions = None
        self._condition_value = None
        self.discriminator = None

        self.scenario_id = scenario_id
        if data_type is not None:
            self.data_type = data_type
        if time is not None:
            self.time = time
        if filter_conditions is not None:
            self.filter_conditions = filter_conditions
        self.condition_value = condition_value

    @property
    def scenario_id(self):
        """Gets the scenario_id of this GetFilterModelResultInput.  # noqa: E501


        :return: The scenario_id of this GetFilterModelResultInput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this GetFilterModelResultInput.


        :param scenario_id: The scenario_id of this GetFilterModelResultInput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def data_type(self):
        """Gets the data_type of this GetFilterModelResultInput.  # noqa: E501


        :return: The data_type of this GetFilterModelResultInput.  # noqa: E501
        :rtype: SysWdDataTypeEnum
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this GetFilterModelResultInput.


        :param data_type: The data_type of this GetFilterModelResultInput.  # noqa: E501
        :type: SysWdDataTypeEnum
        """

        self._data_type = data_type

    @property
    def time(self):
        """Gets the time of this GetFilterModelResultInput.  # noqa: E501


        :return: The time of this GetFilterModelResultInput.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this GetFilterModelResultInput.


        :param time: The time of this GetFilterModelResultInput.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def filter_conditions(self):
        """Gets the filter_conditions of this GetFilterModelResultInput.  # noqa: E501


        :return: The filter_conditions of this GetFilterModelResultInput.  # noqa: E501
        :rtype: FilterConditionEnum
        """
        return self._filter_conditions

    @filter_conditions.setter
    def filter_conditions(self, filter_conditions):
        """Sets the filter_conditions of this GetFilterModelResultInput.


        :param filter_conditions: The filter_conditions of this GetFilterModelResultInput.  # noqa: E501
        :type: FilterConditionEnum
        """

        self._filter_conditions = filter_conditions

    @property
    def condition_value(self):
        """Gets the condition_value of this GetFilterModelResultInput.  # noqa: E501


        :return: The condition_value of this GetFilterModelResultInput.  # noqa: E501
        :rtype: list[float]
        """
        return self._condition_value

    @condition_value.setter
    def condition_value(self, condition_value):
        """Sets the condition_value of this GetFilterModelResultInput.


        :param condition_value: The condition_value of this GetFilterModelResultInput.  # noqa: E501
        :type: list[float]
        """

        self._condition_value = condition_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetFilterModelResultInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetFilterModelResultInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class GetInitialConditionOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hotstart_scenario': 'str',
        'river_hotstart_file': 'str',
        'pipe_hotstart_file': 'str',
        'm2_d_hotstart_file': 'str'
    }

    attribute_map = {
        'hotstart_scenario': 'hotstartScenario',
        'river_hotstart_file': 'riverHotstartFile',
        'pipe_hotstart_file': 'pipeHotstartFile',
        'm2_d_hotstart_file': 'm2DHotstartFile'
    }

    def __init__(self, hotstart_scenario=None, river_hotstart_file=None, pipe_hotstart_file=None, m2_d_hotstart_file=None, local_vars_configuration=None):  # noqa: E501
        """GetInitialConditionOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._hotstart_scenario = None
        self._river_hotstart_file = None
        self._pipe_hotstart_file = None
        self._m2_d_hotstart_file = None
        self.discriminator = None

        self.hotstart_scenario = hotstart_scenario
        self.river_hotstart_file = river_hotstart_file
        self.pipe_hotstart_file = pipe_hotstart_file
        self.m2_d_hotstart_file = m2_d_hotstart_file

    @property
    def hotstart_scenario(self):
        """Gets the hotstart_scenario of this GetInitialConditionOutput.  # noqa: E501

        热启动方案ID hotstart scenario ID  # noqa: E501

        :return: The hotstart_scenario of this GetInitialConditionOutput.  # noqa: E501
        :rtype: str
        """
        return self._hotstart_scenario

    @hotstart_scenario.setter
    def hotstart_scenario(self, hotstart_scenario):
        """Sets the hotstart_scenario of this GetInitialConditionOutput.

        热启动方案ID hotstart scenario ID  # noqa: E501

        :param hotstart_scenario: The hotstart_scenario of this GetInitialConditionOutput.  # noqa: E501
        :type: str
        """

        self._hotstart_scenario = hotstart_scenario

    @property
    def river_hotstart_file(self):
        """Gets the river_hotstart_file of this GetInitialConditionOutput.  # noqa: E501

        河道模型热启动文件 river hotstart file  # noqa: E501

        :return: The river_hotstart_file of this GetInitialConditionOutput.  # noqa: E501
        :rtype: str
        """
        return self._river_hotstart_file

    @river_hotstart_file.setter
    def river_hotstart_file(self, river_hotstart_file):
        """Sets the river_hotstart_file of this GetInitialConditionOutput.

        河道模型热启动文件 river hotstart file  # noqa: E501

        :param river_hotstart_file: The river_hotstart_file of this GetInitialConditionOutput.  # noqa: E501
        :type: str
        """

        self._river_hotstart_file = river_hotstart_file

    @property
    def pipe_hotstart_file(self):
        """Gets the pipe_hotstart_file of this GetInitialConditionOutput.  # noqa: E501

        管网模型热启动文件 pipe hotstart file  # noqa: E501

        :return: The pipe_hotstart_file of this GetInitialConditionOutput.  # noqa: E501
        :rtype: str
        """
        return self._pipe_hotstart_file

    @pipe_hotstart_file.setter
    def pipe_hotstart_file(self, pipe_hotstart_file):
        """Sets the pipe_hotstart_file of this GetInitialConditionOutput.

        管网模型热启动文件 pipe hotstart file  # noqa: E501

        :param pipe_hotstart_file: The pipe_hotstart_file of this GetInitialConditionOutput.  # noqa: E501
        :type: str
        """

        self._pipe_hotstart_file = pipe_hotstart_file

    @property
    def m2_d_hotstart_file(self):
        """Gets the m2_d_hotstart_file of this GetInitialConditionOutput.  # noqa: E501

        二维模型热启动文件 2D hotstart file  # noqa: E501

        :return: The m2_d_hotstart_file of this GetInitialConditionOutput.  # noqa: E501
        :rtype: str
        """
        return self._m2_d_hotstart_file

    @m2_d_hotstart_file.setter
    def m2_d_hotstart_file(self, m2_d_hotstart_file):
        """Sets the m2_d_hotstart_file of this GetInitialConditionOutput.

        二维模型热启动文件 2D hotstart file  # noqa: E501

        :param m2_d_hotstart_file: The m2_d_hotstart_file of this GetInitialConditionOutput.  # noqa: E501
        :type: str
        """

        self._m2_d_hotstart_file = m2_d_hotstart_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetInitialConditionOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetInitialConditionOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    message-center-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_message_service.configuration import Configuration


class AddMsgTypeTempLocalInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'msg_type': 'str',
        'language': 'str',
        'msg_template': 'MsgTemplateObj'
    }

    attribute_map = {
        'msg_type': 'msgType',
        'language': 'language',
        'msg_template': 'msgTemplate'
    }

    def __init__(self, msg_type=None, language=None, msg_template=None, local_vars_configuration=None):  # noqa: E501
        """AddMsgTypeTempLocalInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._msg_type = None
        self._language = None
        self._msg_template = None
        self.discriminator = None

        self.msg_type = msg_type
        self.language = language
        self.msg_template = msg_template

    @property
    def msg_type(self):
        """Gets the msg_type of this AddMsgTypeTempLocalInput.  # noqa: E501

        消息类型  <br> message's type   # noqa: E501

        :return: The msg_type of this AddMsgTypeTempLocalInput.  # noqa: E501
        :rtype: str
        """
        return self._msg_type

    @msg_type.setter
    def msg_type(self, msg_type):
        """Sets the msg_type of this AddMsgTypeTempLocalInput.

        消息类型  <br> message's type   # noqa: E501

        :param msg_type: The msg_type of this AddMsgTypeTempLocalInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and msg_type is None:  # noqa: E501
            raise ValueError("Invalid value for `msg_type`, must not be `None`")  # noqa: E501

        self._msg_type = msg_type

    @property
    def language(self):
        """Gets the language of this AddMsgTypeTempLocalInput.  # noqa: E501

        模板语言  <br> tempalte's language   # noqa: E501

        :return: The language of this AddMsgTypeTempLocalInput.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AddMsgTypeTempLocalInput.

        模板语言  <br> tempalte's language   # noqa: E501

        :param language: The language of this AddMsgTypeTempLocalInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and language is None:  # noqa: E501
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def msg_template(self):
        """Gets the msg_template of this AddMsgTypeTempLocalInput.  # noqa: E501


        :return: The msg_template of this AddMsgTypeTempLocalInput.  # noqa: E501
        :rtype: MsgTemplateObj
        """
        return self._msg_template

    @msg_template.setter
    def msg_template(self, msg_template):
        """Sets the msg_template of this AddMsgTypeTempLocalInput.


        :param msg_template: The msg_template of this AddMsgTypeTempLocalInput.  # noqa: E501
        :type: MsgTemplateObj
        """
        if self.local_vars_configuration.client_side_validation and msg_template is None:  # noqa: E501
            raise ValueError("Invalid value for `msg_template`, must not be `None`")  # noqa: E501

        self._msg_template = msg_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddMsgTypeTempLocalInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddMsgTypeTempLocalInput):
            return True

        return self.to_dict() != other.to_dict()
